@@ -56,11 +56,12 @@ static int r_jws_extract_header(jws_t * jws, json_t * j_header, int x5u_flags) {
     
     if (json_object_get(j_header, "jwk") != NULL) {
       r_jwk_init(&jwk);
-      if (r_jwk_import_from_json_t(jwk, json_object_get(j_header, "jwk")) != RHN_OK) {
+      if (r_jwk_import_from_json_t(jwk, json_object_get(j_header, "jwk")) == RHN_OK) {
         if (r_jwks_append_jwk(jws->jwks_pubkey, jwk) != RHN_OK) {
           ret = RHN_ERROR;
         }
       } else {
+        y_log_message(Y_LOG_LEVEL_ERROR, "r_jws_extract_header - Error parsing header jwk");
         ret = RHN_ERROR_PARAM;
       }
       r_jwk_free(jwk);
@@ -73,6 +74,7 @@ static int r_jws_extract_header(jws_t * jws, json_t * j_header, int x5u_flags) {
           ret = RHN_ERROR;
         }
       } else {
+        y_log_message(Y_LOG_LEVEL_ERROR, "r_jws_extract_header - Error importing x5c or x5u");
         ret = RHN_ERROR_PARAM;
       }
       r_jwk_free(jwk);
@@ -189,8 +191,8 @@ static unsigned char * r_jws_sign_hmac(jws_t * jws, jwk_t * jwk) {
   return to_return;
 }
 
-static unsigned char * r_jws_sign_rsa(jws_t * jws, jwk_t * jwk, int x5u_flags) {
-  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk, x5u_flags);
+static unsigned char * r_jws_sign_rsa(jws_t * jws, jwk_t * jwk) {
+  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk);
   gnutls_datum_t body_dat, sig_dat;
   unsigned char * to_return = NULL;
   int alg = GNUTLS_DIG_NULL, res, flag = 0;
@@ -259,9 +261,9 @@ static unsigned char * r_jws_sign_rsa(jws_t * jws, jwk_t * jwk, int x5u_flags) {
   return to_return;
 }
 
-static unsigned char * r_jws_sign_ecdsa(jws_t * jws, jwk_t * jwk, int x5u_flags) {
+static unsigned char * r_jws_sign_ecdsa(jws_t * jws, jwk_t * jwk) {
 #if GNUTLS_VERSION_NUMBER >= 0x030600
-  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk, x5u_flags);
+  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk);
   gnutls_datum_t body_dat, sig_dat, r, s;
   unsigned char * binary_sig = NULL, * to_return = NULL;
   int alg = GNUTLS_DIG_NULL, res;
@@ -337,14 +339,13 @@ static unsigned char * r_jws_sign_ecdsa(jws_t * jws, jwk_t * jwk, int x5u_flags)
 #else
   (void)(jws);
   (void)(jwk);
-  (void)(x5u_flags);
   return NULL;
 #endif
 }
 
-static unsigned char * r_jws_sign_eddsa(jws_t * jws, jwk_t * jwk, int x5u_flags) {
+static unsigned char * r_jws_sign_eddsa(jws_t * jws, jwk_t * jwk) {
 #if GNUTLS_VERSION_NUMBER >= 0x030600
-  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk, x5u_flags);
+  gnutls_privkey_t privkey = r_jwk_export_to_gnutls_privkey(jwk);
   gnutls_datum_t body_dat, sig_dat;
   unsigned char * to_return = NULL;
   int res;
@@ -379,7 +380,6 @@ static unsigned char * r_jws_sign_eddsa(jws_t * jws, jwk_t * jwk, int x5u_flags)
 #else
   (void)(jws);
   (void)(jwk);
-  (void)(x5u_flags);
   return NULL;
 #endif
 }
@@ -1156,6 +1156,7 @@ int r_jws_parsen(jws_t * jws, const char * jws_str, size_t jws_str_len, int x5u_
           
           j_header = json_loads(str_header, JSON_DECODE_ANY, NULL);
           if (r_jws_extract_header(jws, j_header, x5u_flags) != RHN_OK) {
+            y_log_message(Y_LOG_LEVEL_DEBUG, "r_jws_parsen - error extracting header params");
             ret = RHN_ERROR_PARAM;
             break;
           }
@@ -1264,6 +1265,9 @@ int r_jws_verify_signature(jws_t * jws, jwk_t * jwk_pubkey, int x5u_flags) {
             ret = RHN_ERROR_INVALID;
           }
           break;
+        case R_JWA_ALG_ES256K:
+          ret = RHN_ERROR_UNSUPPORTED;
+          break;
         case R_JWA_ALG_NONE:
           ret = RHN_OK;
           break;
@@ -1323,7 +1327,7 @@ char * r_jws_serialize(jws_t * jws, jwk_t * jwk_privkey, int x5u_flags) {
       case R_JWA_ALG_PS512:
         if (r_jwk_key_type(jwk, NULL, x5u_flags) & R_KEY_TYPE_RSA) {
           o_free(jws->signature_b64url);
-          jws->signature_b64url = r_jws_sign_rsa(jws, jwk, x5u_flags);
+          jws->signature_b64url = r_jws_sign_rsa(jws, jwk);
         }
         break;
       case R_JWA_ALG_ES256:
@@ -1331,20 +1335,23 @@ char * r_jws_serialize(jws_t * jws, jwk_t * jwk_privkey, int x5u_flags) {
       case R_JWA_ALG_ES512:
         if (r_jwk_key_type(jwk, NULL, x5u_flags) & R_KEY_TYPE_ECDSA) {
           o_free(jws->signature_b64url);
-          jws->signature_b64url = r_jws_sign_ecdsa(jws, jwk, x5u_flags);
+          jws->signature_b64url = r_jws_sign_ecdsa(jws, jwk);
         }
         break;
       case R_JWA_ALG_EDDSA:
         if (r_jwk_key_type(jwk, NULL, x5u_flags) & R_KEY_TYPE_EDDSA) {
           o_free(jws->signature_b64url);
-          jws->signature_b64url = r_jws_sign_eddsa(jws, jwk, x5u_flags);
+          jws->signature_b64url = r_jws_sign_eddsa(jws, jwk);
         }
         break;
       case R_JWA_ALG_NONE:
         o_free(jws->signature_b64url);
         jws->signature_b64url = (unsigned char *)o_strdup("");
         break;
+      case R_JWA_ALG_ES256K:
       default:
+        o_free(jws->signature_b64url);
+        jws->signature_b64url = NULL;
         y_log_message(Y_LOG_LEVEL_ERROR, "r_jws_serialize - Unsupported algorithm");
         break;
     }
